@@ -352,13 +352,19 @@ class PQtFileDialog(PFileDialogBase):
             None, "Select Folder", curdir
         ))
     
-    def open_filename(self, path, filter):
-        return qt.QFileDialog.getOpenFileName(None, "Open",
-                                              path, filter)[0]
+    def _translate_filter_item(self, caption, ext_str):
+        return "{} ({})".format(caption, ext_str)
     
-    def save_filename(self, path, filter):
-        return qt.QFileDialog.getSaveFileName(None, "Save",
-                                              path, filter)[0]
+    ext_sep = " "
+    filter_sep = ";;"
+    
+    def _open_filename(self, path, filter, selected_filter):
+        return qt.QFileDialog.getOpenFileName(self.parent, "Open",
+                                              path, filter, selected_filter)[0]
+    
+    def _save_filename(self, path, filter, selected_filter):
+        return qt.QFileDialog.getSaveFileName(self.parent, "Save",
+                                              path, filter, selected_filter)[0]
 
 
 class PQtAboutDialog(PAboutDialogBase):
